@@ -28,6 +28,7 @@ LOG = log.getLogger(__name__)
 
 OPTS = [
     cfg.StrOpt('backend_url',
+               secret=True,
                help='The backend URL to use for distributed coordination. If '
                     'left empty, alarm evaluation won\'t do workload '
                     'partitioning and will only function correctly if a '
@@ -37,12 +38,6 @@ OPTS = [
                  deprecated_name='heartbeat',
                  help='Number of seconds between heartbeats for distributed '
                       'coordination.'),
-    cfg.FloatOpt('check_watchers',
-                 default=10.0,
-                 deprecated_for_removal=True,
-                 deprecated_reason='This parameter is no longer used.',
-                 help='Number of seconds between checks to see if group '
-                      'membership has changed'),
     cfg.IntOpt('retry_backoff',
                default=1,
                help='Retry backoff factor when retrying to connect with'
